ContentBounds

Struct ContentBounds 

pub struct ContentBounds {
    pub size: Option<SizeU>,
    pub origin: Option<Vec_>,
    /* private fields */
}
Defines the size and position of a piece of graphical content.

The bounds of the content are assumed to be rectangular.

Fields

size: Option<SizeU>

The size of the content, defined in its parent view’s coordinate space.

For example, a parent view with size 1280x800 is assumed to have a useful coordinate space from (0, 0) to (1280, 800). A piece of content that’s one-fourth the area of the parent view would have size 640x400.

origin: Option<Vec_>

The location of the top-left corner of the content’s origin, defined in the parent view’s coordinate space.

Returning to the example above, we could position the content to cover the bottom-right quadrant of the parent by assigning an origin of (640, 400).